@@ -5,6 +5,7 @@ plugins {
 // Fake NPM task that would normally execute npm with its provided arguments
 open class NpmTask : DefaultTask() {
 
+    @get:Input
     val args = project.objects.listProperty<String>()
 
     @TaskAction
@@ -18,7 +19,7 @@ open class NpmTask : DefaultTask() {
 }
 
 // tag::bundle-task[]
-task<NpmTask>("bundle") {
+tasks.register<NpmTask>("bundle") {
     args.set(listOf("run", "bundle"))
 
     outputs.cacheIf { true }
@@ -36,7 +37,7 @@ task<NpmTask>("bundle") {
 }
 // end::bundle-task[]
 
-task("printBundle") {
+tasks.register("printBundle") {
     dependsOn("bundle")
     doLast {
         println(file("$buildDir/bundle.js").readText())
