@@ -34,15 +34,21 @@ sourceSets {
     }
 }
 
+// tag::register_variant_extra_jars[]
 java {
     registerFeature("mongodbSupport") {
         usingSourceSet(sourceSets["mongodbSupport"])
+// end::register_variant[]
+        withJavadocJar()
+        withSourcesJar()
+// tag::register_variant2[]
     }
 }
-// end::register_variant[]
+// end::register_variant2[]
+// end::register_variant_extra_jars[]
 
 // tag::variant_dependencies[]
 dependencies {
     "mongodbSupportImplementation"("org.mongodb:mongodb-driver-sync:3.9.1")
 }
-// end::variant_dependencies[]
\ No newline at end of file
+// end::variant_dependencies[]
