@@ -3,7 +3,7 @@ repositories {
 }
 
 val implementation by configurations.creating
-val runtime by configurations.creating
+val runtimeOnly by configurations.creating
 
 // tag::define-dependency[]
 dependencies {
@@ -21,12 +21,12 @@ task("listJars") {
 
 // tag::module-dependencies[]
 dependencies {
-    runtime(group = "org.springframework", name = "spring-core", version = "2.5")
-    runtime("org.springframework:spring-aop:2.5")
-    runtime("org.hibernate:hibernate:3.0.5") {
+    runtimeOnly(group = "org.springframework", name = "spring-core", version = "2.5")
+    runtimeOnly("org.springframework:spring-aop:2.5")
+    runtimeOnly("org.hibernate:hibernate:3.0.5") {
         isTransitive = true
     }
-    runtime(group = "org.hibernate", name = "hibernate", version = "3.0.5") {
+    runtimeOnly(group = "org.hibernate", name = "hibernate", version = "3.0.5") {
         isTransitive = true
     }
 }
@@ -34,7 +34,7 @@ dependencies {
 
 // tag::file-dependencies[]
 dependencies {
-    runtime(files("libs/a.jar", "libs/b.jar"))
-    runtime(fileTree("libs") { include("*.jar") })
+    runtimeOnly(files("libs/a.jar", "libs/b.jar"))
+    runtimeOnly(fileTree("libs") { include("*.jar") })
 }
 // end::file-dependencies[]
