@@ -11,7 +11,7 @@ dependencies {
     implementation("log4j:log4j:1.2.17")
 }
 
-task("printArtifactNames") {
+tasks.register("printArtifactNames") {
     doLast {
         val libraryNames = configurations.compileClasspath.get().map { it.name }
         logger.quiet(libraryNames.toString())
