@@ -9,20 +9,20 @@ tasks.register<Zip>("myZip") {
     from("somedir")
 
     doLast {
-        println(archiveName)
-        println(relativePath(destinationDir))
-        println(relativePath(archivePath))
+        println(archiveFileName.get())
+        println(relativePath(destinationDirectory))
+        println(relativePath(archiveFile))
     }
 }
 // end::zip-task[]
 
 // tag::zip-task-with-custom-base-name[]
 tasks.register<Zip>("myCustomZip") {
-    baseName = "customName"
+    archiveBaseName.set("customName")
     from("somedir")
 
     doLast {
-        println(archiveName)
+        println(archiveFileName.get())
     }
 }
 // end::zip-task-with-custom-base-name[]
