@@ -1,10 +1,10 @@
-val buildInfo = task<BuildInfo>("buildInfo") {
+val buildInfo by tasks.registering(BuildInfo::class) {
     version = project.version.toString()
     outputFile = file("$buildDir/generated-resources/build-info.properties")
 }
 
 sourceSets {
     main {
-        output.dir(buildInfo.outputFile.parentFile, "builtBy" to buildInfo)
+        output.dir(buildInfo.get().outputFile.parentFile, "builtBy" to buildInfo)
     }
 }
