@@ -35,7 +35,7 @@ publishing {
 // end::configure-publishing[]
 
 // tag::configure-generate-task[]
-tasks.withType<GenerateMavenPom>().all {
+tasks.withType<GenerateMavenPom>().configureEach {
     val matcher = Regex("""generatePomFileFor(\w+)Publication""").matchEntire(name)
     val publicationName = matcher?.let { it.groupValues[1] }
     destination = file("$buildDir/poms/$publicationName-pom.xml")
