@@ -4,6 +4,7 @@ open class GreetingToFileTask : DefaultTask() {
 
     var destination: Any? = null
 
+    @OutputFile
     fun getDestination(): File {
         return project.file(destination!!)
     }
@@ -18,11 +19,11 @@ open class GreetingToFileTask : DefaultTask() {
 // end::task[]
 
 // tag::config[]
-task<GreetingToFileTask>("greet") {
-    destination = provider { project.extra["greetingFile"]!! }
+tasks.register<GreetingToFileTask>("greet") {
+    destination = { project.extra["greetingFile"]!! }
 }
 
-task("sayGreeting") {
+tasks.register("sayGreeting") {
     dependsOn("greet")
     doLast {
         println(file(project.extra["greetingFile"]!!).readText())
